#line 2 "llsphinxql.c"

#line 4 "llsphinxql.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 139
#define YY_END_OF_BUFFER 140
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[546] =
    {   0,
        0,    0,    0,    0,  140,  138,  136,  136,  138,  138,
      138,  138,  125,  138,  138,  138,  138,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  138,    2,
      139,    2,  136,  115,    0,  120,    0,    0,  122,  137,
        1,  121,  125,  130,  130,  119,  117,  116,  118,    0,
      131,  131,  131,  131,  129,  129,  129,  129,  129,    8,
      129,  129,  129,  129,  129,   17,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,   47,   48,   54,  129,  129,  129,  129,

      129,  129,  129,  129,  129,  129,  129,  129,   72,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  102,  129,  129,  129,  129,  129,  129,  129,
      129,  129,    0,    0,    3,    0,  123,  123,  137,  121,
        0,    0,  124,  132,  131,  131,  126,  131,    6,  129,
      129,    7,    9,  129,   12,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
       32,  129,  129,  129,  129,  129,  129,   39,  129,  129,
      129,  129,  129,  129,  129,   52,  129,  129,  129,  129,
      129,  129,   61,  129,   63,   64,  129,  129,   68,  129,

      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,   90,  129,  129,
      129,  129,   98,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,    0,  135,    0,  123,
        0,  122,    0,  121,  124,    0,  132,  131,  131,  129,
      129,  129,  129,  129,  129,  129,   16,   18,  129,  129,
      129,  129,  129,  129,  129,  129,  129,   29,  129,  129,
       34,  129,  129,  129,  129,   40,  129,  129,  129,  129,
      129,  129,  129,   53,  129,   56,  129,   58,  129,  129,
       62,  129,  129,   69,  129,  129,   74,  129,  129,  129,

       79,   80,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,   93,  129,  129,  129,  129,  129,  129,
      129,  104,  129,  106,  129,  129,  129,  129,  129,  129,
      129,  129,  134,  122,  133,  131,  131,    4,    5,  129,
      129,   13,  129,  129,  129,   20,  129,  129,  129,   25,
      129,  129,  129,  129,  129,  129,   35,   36,   37,   38,
      129,  129,   43,  129,   49,  129,  129,  129,   57,   59,
       60,   65,   67,  129,  129,   73,  129,  129,  129,  129,
       84,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,   95,  129,  129,   99,  129,  129,  129,  129,  129,

      129,  129,  129,  129,  113,  129,  133,  128,  131,   10,
      129,  129,   15,  129,  129,   22,   23,   26,  129,   28,
      129,  129,   33,  129,   42,  129,  129,   46,   50,  129,
      129,  129,  129,   70,   75,  129,  129,  129,  129,  129,
      129,  129,  129,   88,  129,  129,  129,   94,   96,   97,
      100,  129,  129,  129,  129,  108,  109,  129,  129,  112,
      114,  127,  129,   14,  129,  129,  129,  129,  129,  129,
      129,   44,  129,   51,  129,   66,  129,   76,   77,  129,
      129,  129,   83,   85,  129,   87,  129,   92,  129,  101,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,

       30,   31,   41,  129,  129,   71,   78,  129,  129,   86,
      129,   91,  129,  105,  129,  129,  111,  129,   19,   21,
       24,   27,  129,   55,  129,  129,  129,  129,  129,  110,
       11,  129,  129,   82,  129,  129,  129,  129,   81,  129,
      103,  107,   45,   89,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    1,    1,    1,    1,    1,    5,    1,
        1,    6,    7,    1,    8,    9,   10,   11,   11,   11,
       11,   12,   11,   13,   11,   11,   11,   14,    1,   15,
       16,   17,    1,   18,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
        1,   45,    1,    1,   46,   47,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       62,   63,   35,   64,   65,   66,   67,   68,   69,   70,
       71,   72,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[73] =
    {   0,
        1,    2,    2,    1,    1,    1,    1,    1,    3,    1,
        4,    4,    4,    1,    1,    1,    1,    5,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    1,    6,    7,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6
    } ;

static yyconst flex_int16_t yy_base[562] =
    {   0,
        0,    0,   70,   71,  261, 1195,   76,   78,  242,   70,
       80,  225,   75,  210,   73,  203,   76,  124,   73,   76,
      124,    0,  163,   69,   66,  126,   71,  114,  181,  184,
      131,  176,  219,  221,  236,   89,   82,  263,   83, 1195,
     1195,  208,  116, 1195,  108, 1195,  139,  290,  252,    0,
     1195,  283,  301,  206,  314, 1195, 1195, 1195, 1195,    0,
        0,  135,  147,  158,    0,  183,  184,  135,  194,  200,
      175,  199,  291,  214,  216,    0,  240,  289,  300,  257,
      190,  303,  301,  238,  284,  313,  303,  284,  299,  312,
      314,  316,  311,    0,  349,  319,  321,  324,  346,  342,

      336,  350,  366,  359,  359,  347,  361,  355,  372,  377,
      362,  366,  409,  373,  378,  399,  376,  378,  412,  391,
      413,  406,    0,  434,  411,  428,  428,  425,  416,  427,
      433,  428,  162,  445, 1195,  129,    0,  491,    0,  494,
      501,  475,  507,  170,    0,  454,    0,  441,    0,  439,
      458,    0,    0,  492,    0,  468,  474,  495,  493,  495,
      491,  497,  500,  500,  500,  514,  515,  512,  515,  500,
        0,  521,  508,  521,  510,  526,  511,    0,  518,  529,
      533,  518,  541,  546,  549,  554,  550,  549,  560,  561,
      559,  567,    0,  570,    0,    0,  553,  569,    0,  563,

      567,  572,  564,  574,  576,  581,  581,  582,  572,  588,
      597,  572,  578,  582,  603,  603,  598,  600,  599,  622,
      608,  615,    0,  617,  625,  618,  628,  629,  620,  635,
      606,  630,  626,  636,  628,  636,  124, 1195,  112,    0,
      682,  685,  688,  691,  694,    0,  146,  652,  660,  650,
      672,  688,  683,  679,  689,  683,    0,    0,  698,  689,
      700,  689,  694,  685,  686,  705,  689,  692,  702,  700,
        0,  694,  710,  697,  711,    0,  704,  724,  711,  721,
      715,  725,  739,    0,  746,    0,  737,    0,  731,  745,
        0,  746,  738,    0,  745,  744,    0,  750,  754,  757,

        0,    0,  752,  752,  768,  769,  754,  771,  770,  774,
      779,  772,  774,    0,  773,  771,  772,  782,  796,  803,
      788,    0,  802,    0,  795,  791,  808,  813,  807,  809,
      813,  811, 1195,  829,    0,  806,  819,    0,    0,  820,
      827,    0,  826,  816,  829,    0,  818,  826,  824,    0,
      836,  847,  845,  842,  838,  848,    0,    0,    0,    0,
      846,  847,  861,  855,    0,  845,  862,  851,    0,    0,
        0,  109,    0,  859,  859,    0,  860,  863,  857,  870,
        0,  863,  882,  872,  886,  885,  874,  883,  883,  886,
      896,    0,  888,  901,  891,  908,  912,  916,  905,  915,

      904,  919,  911,  908,    0,  912,    0,    0,  911,    0,
      911,  919,    0,  916,  925,    0,  919,    0,  921,    0,
      941,  941,    0,  930,    0,  923,  949,    0,    0,  939,
      944,  108,  932,    0,  942,  960,  952,  960,  969,  966,
      956,  974,  955,    0,  971,  969,  977,    0,    0,    0,
        0,  968,  985,  970,  982,    0,    0,  980,  986,    0,
        0,    0,  976,    0,  992,  986,  997,  999, 1000,  988,
      996,    0,  996,    0,  999,    0, 1011,    0,    0, 1008,
     1016, 1023,    0,    0, 1016,    0, 1003,    0, 1013,    0,
     1015, 1032, 1021, 1033, 1023, 1039, 1028, 1033, 1045, 1032,

        0,    0,    0, 1039, 1041,    0,    0, 1037, 1047,    0,
     1060,    0, 1053,    0, 1044, 1046,    0, 1049,    0,    0,
        0,    0, 1068,    0, 1057, 1067, 1075, 1065, 1076,    0,
        0, 1082, 1080,    0, 1075, 1075, 1090, 1077,    0, 1090,
        0,    0,    0,    0, 1195, 1143, 1150, 1156, 1160, 1162,
     1165,  105, 1168, 1171,  101, 1174, 1177, 1181, 1185,   98,
     1188
    } ;

static yyconst flex_int16_t yy_def[562] =
    {   0,
      545,    1,  546,  546,  545,  545,  545,  545,  545,  547,
      548,  545,  549,  545,  545,  545,  550,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  552,  545,
      545,  545,  545,  545,  547,  545,  547,  548,  553,  554,
      545,  545,  549,  549,  549,  545,  545,  545,  545,  555,
      556,  556,  556,  556,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,

      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  557,  557,  545,  547,  558,  558,  554,  545,
      545,  545,  549,  559,  556,  556,  556,  556,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,

      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  557,  545,  557,  558,
      545,  558,  545,  545,  545,  560,  559,  556,  556,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,

      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  545,  545,  561,  556,  556,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,

      551,  551,  551,  551,  551,  551,  561,  556,  556,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  556,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,

      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,    0,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545
    } ;

static yyconst flex_int16_t yy_nxt[1268] =
    {   0,
        6,    7,    8,    9,   10,    6,    6,    6,   11,   12,
       13,   13,   13,   14,   15,    6,   16,   17,   18,   19,
       20,   21,   22,   23,   24,   25,   26,   27,   22,   28,
       29,   30,   31,   32,   22,   33,   34,   35,   36,   37,
       38,   22,   22,   22,    6,   22,   39,   18,   19,   20,
       21,   22,   23,   24,   25,   26,   27,   22,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   22,
       22,   22,   41,   41,   46,   42,   42,   43,   43,   43,
       43,   48,   48,   52,   93,   53,   53,   53,   57,   58,
       49,   49,   49,   60,   77,   73,   62,   55,   91,   74,

      128,   78,   63,  335,   92,   75,  144,   97,   79,  134,
      133,   80,   46,   93,   47,   76,   64,   43,   43,  476,
      126,  432,  127,   77,   73,   62,   55,   91,   74,  128,
       78,   63,   92,   46,   75,   97,   98,   79,  134,   80,
       99,  545,   81,   76,   64,   66,   82,   94,   67,  126,
       83,  127,   47,   68,  246,   69,   84,   95,  333,   85,
       70,   71,   96,   72,  108,   98,  109,  146,  147,   99,
      238,   81,  151,   47,   66,   82,   94,   67,  246,   83,
      148,   86,   68,  136,   69,   84,   95,   85,   70,   71,
       96,   72,   87,  108,  109,   88,  146,  147,   89,  100,

      151,   90,  105,  101,  149,  110,  150,  102,  238,  148,
       86,  111,  154,  103,  545,  152,  106,  135,   59,  104,
      153,   87,  107,  155,   88,   56,   89,  167,  100,   90,
       51,  105,  101,  149,  110,  150,  102,  112,  158,  111,
      154,  113,  103,  116,  152,  106,  117,  104,  159,  153,
      107,  114,  155,  118,  121,  167,  115,   44,  119,  120,
      545,  122,   49,   49,   49,  545,  112,  158,  123,  160,
      113,  124,  116,  545,  138,  117,  172,  159,  125,  166,
      114,  129,  118,  121,  115,  130,  119,  120,  131,  132,
      122,   48,   48,  140,  140,  140,  545,  123,  160,  124,

      545,  545,  545,  138,  172,  141,  125,  161,  166,   52,
      129,   53,   53,   53,  130,  156,  173,  131,  132,  178,
      142,  142,  545,   55,  143,  143,  143,  162,  157,  163,
      164,  179,  168,  174,  141,  176,  161,  170,  165,  169,
      171,  177,  175,  180,  156,  173,  181,  178,  182,  545,
      183,  187,   55,  188,  545,  162,  157,  545,  163,  164,
      179,  168,  174,  189,  176,  170,  165,  169,  171,  177,
      184,  175,  180,  194,  190,  181,  191,  182,  183,  192,
      187,  195,  188,  193,  199,  185,  186,  196,  197,  198,
      200,  189,  201,  202,  205,  203,  206,  207,  545,  184,

      545,  194,  213,  190,  214,  191,  545,  192,  219,  220,
      195,  193,  199,  185,  186,  204,  196,  197,  198,  200,
      201,  223,  202,  205,  203,  206,  207,  208,  215,  209,
      221,  213,  224,  214,  216,  217,  218,  219,  220,  210,
      545,  225,  211,  204,  228,  545,  212,  222,  229,  230,
      223,  233,  226,  234,  231,  235,  208,  215,  209,  221,
      232,  224,  216,  217,  218,  236,  239,  249,  210,  225,
      250,  211,  227,  228,  212,  222,  545,  229,  230,  233,
      251,  226,  234,  231,  235,  245,  245,  245,  232,  545,
      545,  238,  248,  236,  254,  239,  249,  241,  241,  250,

      227,  242,  242,  242,  140,  140,  140,  243,  243,  251,
      252,  244,  244,  244,  255,  545,  141,  143,  143,  143,
      248,  256,  257,  254,  258,  545,  259,  253,  260,  261,
      263,  264,  265,  266,  267,  268,  545,  269,  262,  252,
      270,  271,  255,  272,  274,  141,  273,  275,  276,  277,
      256,  257,  278,  258,  259,  253,  279,  260,  261,  263,
      264,  265,  266,  267,  268,  269,  262,  280,  281,  270,
      271,  282,  272,  274,  273,  275,  283,  276,  277,  285,
      286,  278,  287,  288,  279,  289,  284,  290,  291,  545,
      292,  293,  294,  295,  296,  297,  280,  281,  298,  299,

      282,  300,  301,  302,  303,  283,  304,  308,  285,  286,
      307,  287,  288,  309,  289,  284,  290,  291,  292,  305,
      293,  294,  295,  296,  297,  310,  306,  298,  299,  311,
      300,  301,  302,  303,  312,  304,  308,  313,  307,  314,
      315,  318,  309,  316,  327,  317,  319,  320,  305,  321,
      322,  324,  325,  326,  310,  306,  328,  329,  311,  323,
      330,  332,  312,  331,  545,  313,  545,  314,  545,  315,
      318,  316,  327,  317,  545,  319,  320,  545,  321,  322,
      324,  325,  326,  336,  337,  328,  329,  338,  323,  330,
      332,  331,  334,  334,  334,  242,  242,  242,  244,  244,

      244,  244,  244,  244,  245,  245,  245,  339,  340,  341,
      342,  343,  336,  337,  344,  338,  345,  346,  347,  348,
      349,  545,  350,  351,  352,  545,  353,  354,  355,  356,
      545,  357,  358,  545,  359,  339,  360,  340,  341,  342,
      343,  361,  362,  344,  363,  345,  346,  347,  348,  349,
      350,  351,  364,  352,  353,  354,  365,  355,  356,  357,
      366,  358,  359,  367,  368,  360,  369,  545,  370,  361,
      371,  362,  372,  363,  373,  374,  377,  375,  545,  376,
      378,  364,  379,  380,  365,  381,  382,  383,  366,  384,
      385,  386,  367,  368,  387,  369,  370,  388,  389,  371,

      390,  372,  373,  391,  374,  377,  375,  376,  392,  378,
      393,  379,  380,  394,  381,  382,  383,  384,  395,  385,
      386,  396,  398,  387,  397,  399,  388,  389,  400,  390,
      401,  402,  391,  403,  404,  405,  392,  406,  393,  334,
      334,  334,  394,  408,  409,  410,  411,  395,  412,  414,
      396,  398,  397,  413,  399,  415,  400,  416,  418,  401,
      402,  417,  403,  404,  405,  419,  406,  420,  421,  422,
      423,  408,  424,  409,  410,  411,  425,  412,  414,  428,
      426,  413,  429,  415,  430,  433,  416,  418,  431,  417,
      434,  435,  436,  438,  419,  437,  420,  421,  422,  423,

      439,  424,  440,  441,  442,  425,  427,  443,  428,  426,
      429,  444,  445,  430,  433,  446,  431,  447,  448,  434,
      435,  436,  438,  437,  449,  450,  545,  451,  439,  452,
      453,  440,  441,  442,  454,  455,  443,  456,  458,  444,
      457,  445,  459,  461,  446,  460,  447,  448,  462,  463,
      464,  466,  449,  465,  450,  451,  467,  468,  452,  453,
      469,  470,  471,  454,  455,  472,  456,  458,  457,  473,
      475,  459,  461,  460,  474,  477,  462,  463,  478,  464,
      466,  465,  479,  480,  467,  468,  481,  482,  483,  469,
      470,  471,  484,  472,  485,  545,  486,  487,  473,  475,

      488,  489,  474,  477,  490,  491,  478,  492,  493,  494,
      495,  479,  480,  496,  497,  481,  482,  483,  498,  499,
      484,  500,  501,  485,  486,  502,  487,  503,  504,  488,
      489,  505,  490,  506,  491,  492,  507,  493,  494,  495,
      508,  496,  509,  497,  510,  545,  511,  498,  499,  512,
      500,  501,  513,  502,  514,  516,  503,  504,  515,  517,
      505,  518,  506,  519,  520,  507,  521,  545,  522,  508,
      523,  509,  524,  510,  511,  525,  526,  512,  527,  528,
      513,  529,  530,  514,  516,  531,  515,  517,  532,  534,
      518,  519,  533,  520,  535,  521,  522,  536,  537,  523,

      538,  524,  539,  525,  540,  526,  541,  527,  528,  529,
      530,  542,  544,  531,  543,  545,  545,  532,  534,  545,
      533,  545,  545,  535,  545,  545,  536,  537,  545,  538,
      545,  539,  545,  540,  545,  541,  545,  545,  545,  545,
      542,  544,  543,   40,   40,   40,   40,   40,   40,   40,
       45,   45,   45,   45,   45,   45,   45,   50,  545,   50,
      545,   50,   54,   54,  545,   54,   61,   61,   65,  545,
       65,  137,  545,  137,  139,  545,  139,  145,  545,  145,
      237,  545,  237,  237,  240,  545,  240,  247,  247,  545,
      247,  407,  545,  407,    5,  545,  545,  545,  545,  545,

      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545
    } ;

static yyconst flex_int16_t yy_chk[1268] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    4,   10,    3,    4,    7,    7,    8,
        8,   11,   11,   13,   25,   13,   13,   13,   15,   15,
       11,   11,   11,   17,   20,   19,   17,   13,   24,   19,

       37,   20,   17,  560,   24,   19,  555,   27,   20,   39,
      552,   20,   45,   25,   10,   19,   17,   43,   43,  432,
       36,  372,   36,   20,   19,   17,   13,   24,   19,   37,
       20,   17,   24,  136,   19,   27,   28,   20,   39,   20,
       28,   47,   21,   19,   17,   18,   21,   26,   18,   36,
       21,   36,   45,   18,  247,   18,   21,   26,  239,   21,
       18,   18,   26,   18,   31,   28,   31,   62,   63,   28,
      237,   21,   68,  136,   18,   21,   26,   18,  144,   21,
       64,   23,   18,   47,   18,   21,   26,   21,   18,   18,
       26,   18,   23,   31,   31,   23,   62,   63,   23,   29,

       68,   23,   30,   29,   66,   32,   67,   29,  133,   64,
       23,   32,   71,   29,   54,   69,   30,   42,   16,   29,
       70,   23,   30,   72,   23,   14,   23,   81,   29,   23,
       12,   30,   29,   66,   32,   67,   29,   33,   74,   32,
       71,   33,   29,   34,   69,   30,   34,   29,   75,   70,
       30,   33,   72,   34,   35,   81,   33,    9,   34,   34,
        5,   35,   49,   49,   49,    0,   33,   74,   35,   77,
       33,   35,   34,    0,   49,   34,   84,   75,   35,   80,
       33,   38,   34,   35,   33,   38,   34,   34,   38,   38,
       35,   48,   48,   52,   52,   52,    0,   35,   77,   35,

       48,   48,   48,   49,   84,   52,   35,   78,   80,   53,
       38,   53,   53,   53,   38,   73,   85,   38,   38,   88,
       55,   55,   55,   53,   55,   55,   55,   78,   73,   79,
       79,   89,   82,   86,   52,   87,   78,   83,   79,   82,
       83,   87,   86,   90,   73,   85,   91,   88,   92,    0,
       93,   96,   53,   97,    0,   78,   73,    0,   79,   79,
       89,   82,   86,   98,   87,   83,   79,   82,   83,   87,
       95,   86,   90,  101,   99,   91,   99,   92,   93,  100,
       96,  102,   97,  100,  106,   95,   95,  103,  104,  105,
      107,   98,  108,  109,  111,  110,  112,  112,    0,   95,

        0,  101,  114,   99,  115,   99,    0,  100,  117,  118,
      102,  100,  106,   95,   95,  110,  103,  104,  105,  107,
      108,  120,  109,  111,  110,  112,  112,  113,  116,  113,
      119,  114,  121,  115,  116,  116,  116,  117,  118,  113,
        0,  122,  113,  110,  125,    0,  113,  119,  126,  127,
      120,  129,  124,  130,  128,  131,  113,  116,  113,  119,
      128,  121,  116,  116,  116,  132,  134,  148,  113,  122,
      150,  113,  124,  125,  113,  119,    0,  126,  127,  129,
      151,  124,  130,  128,  131,  142,  142,  142,  128,    0,
        0,  134,  146,  132,  156,  134,  148,  138,  138,  150,

      124,  138,  138,  138,  140,  140,  140,  141,  141,  151,
      154,  141,  141,  141,  157,  143,  140,  143,  143,  143,
      146,  158,  159,  156,  160,    0,  161,  154,  162,  163,
      164,  165,  166,  167,  168,  169,    0,  170,  163,  154,
      172,  173,  157,  174,  176,  140,  175,  177,  179,  180,
      158,  159,  181,  160,  161,  154,  182,  162,  163,  164,
      165,  166,  167,  168,  169,  170,  163,  183,  184,  172,
      173,  185,  174,  176,  175,  177,  186,  179,  180,  187,
      188,  181,  189,  190,  182,  191,  186,  192,  194,    0,
      197,  198,  200,  201,  202,  203,  183,  184,  204,  205,

      185,  206,  207,  208,  209,  186,  210,  213,  187,  188,
      212,  189,  190,  214,  191,  186,  192,  194,  197,  211,
      198,  200,  201,  202,  203,  215,  211,  204,  205,  216,
      206,  207,  208,  209,  217,  210,  213,  218,  212,  219,
      220,  222,  214,  221,  231,  221,  224,  225,  211,  226,
      227,  228,  229,  230,  215,  211,  232,  233,  216,  227,
      234,  236,  217,  235,    0,  218,    0,  219,    0,  220,
      222,  221,  231,  221,    0,  224,  225,    0,  226,  227,
      228,  229,  230,  248,  249,  232,  233,  250,  227,  234,
      236,  235,  241,  241,  241,  242,  242,  242,  243,  243,

      243,  244,  244,  244,  245,  245,  245,  251,  252,  253,
      254,  255,  248,  249,  256,  250,  259,  260,  261,  262,
      263,    0,  264,  265,  266,    0,  267,  268,  269,  270,
        0,  272,  273,    0,  274,  251,  275,  252,  253,  254,
      255,  277,  278,  256,  279,  259,  260,  261,  262,  263,
      264,  265,  280,  266,  267,  268,  281,  269,  270,  272,
      282,  273,  274,  283,  285,  275,  287,    0,  289,  277,
      290,  278,  292,  279,  293,  295,  298,  295,    0,  296,
      299,  280,  300,  303,  281,  304,  305,  306,  282,  307,
      308,  309,  283,  285,  310,  287,  289,  311,  312,  290,

      313,  292,  293,  315,  295,  298,  295,  296,  316,  299,
      317,  300,  303,  318,  304,  305,  306,  307,  319,  308,
      309,  320,  323,  310,  321,  325,  311,  312,  326,  313,
      327,  328,  315,  329,  330,  331,  316,  332,  317,  334,
      334,  334,  318,  336,  337,  340,  341,  319,  343,  345,
      320,  323,  321,  344,  325,  347,  326,  348,  351,  327,
      328,  349,  329,  330,  331,  352,  332,  353,  354,  355,
      356,  336,  361,  337,  340,  341,  362,  343,  345,  364,
      363,  344,  366,  347,  367,  374,  348,  351,  368,  349,
      375,  377,  378,  380,  352,  379,  353,  354,  355,  356,

      382,  361,  383,  384,  385,  362,  363,  386,  364,  363,
      366,  387,  388,  367,  374,  389,  368,  390,  391,  375,
      377,  378,  380,  379,  393,  394,    0,  395,  382,  396,
      397,  383,  384,  385,  398,  399,  386,  400,  402,  387,
      401,  388,  403,  406,  389,  404,  390,  391,  409,  411,
      412,  415,  393,  414,  394,  395,  417,  419,  396,  397,
      421,  422,  424,  398,  399,  426,  400,  402,  401,  427,
      431,  403,  406,  404,  430,  433,  409,  411,  435,  412,
      415,  414,  436,  437,  417,  419,  438,  439,  440,  421,
      422,  424,  441,  426,  442,    0,  443,  445,  427,  431,

      446,  447,  430,  433,  452,  453,  435,  454,  455,  458,
      459,  436,  437,  463,  465,  438,  439,  440,  466,  467,
      441,  468,  469,  442,  443,  470,  445,  471,  473,  446,
      447,  475,  452,  477,  453,  454,  480,  455,  458,  459,
      481,  463,  482,  465,  485,    0,  487,  466,  467,  489,
      468,  469,  491,  470,  492,  494,  471,  473,  493,  495,
      475,  496,  477,  497,  498,  480,  499,    0,  500,  481,
      504,  482,  505,  485,  487,  508,  509,  489,  511,  513,
      491,  515,  516,  492,  494,  518,  493,  495,  523,  526,
      496,  497,  525,  498,  527,  499,  500,  528,  529,  504,

      532,  505,  533,  508,  535,  509,  536,  511,  513,  515,
      516,  537,  540,  518,  538,    0,    0,  523,  526,    0,
      525,    0,    0,  527,    0,    0,  528,  529,    0,  532,
        0,  533,    0,  535,    0,  536,    0,    0,    0,    0,
      537,  540,  538,  546,  546,  546,  546,  546,  546,  546,
      547,  547,  547,  547,  547,  547,  547,  548,    0,  548,
        0,  548,  549,  549,    0,  549,  550,  550,  551,    0,
      551,  553,    0,  553,  554,    0,  554,  556,    0,  556,
      557,    0,  557,  557,  558,    0,  558,  559,  559,    0,
      559,  561,    0,  561,  545,  545,  545,  545,  545,  545,

      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "sphinxql.l"
#line 2 "sphinxql.l"
#include "yysphinxql.h"

#if USE_WINDOWS
#pragma warning(push,1)
#endif

// warning, lexer generator dependent!
// this macro relies on that in flex yytext points to the actual location in the buffer
#define YYSTOREBOUNDS \
	{ \
		lvalp->m_iStart = yytext - pParser->m_pBuf; \
		lvalp->m_iEnd = lvalp->m_iStart + yyleng; \
		pParser->m_pLastTokenStart = yytext; \
	}


#line 913 "llsphinxql.c"

#define INITIAL 0
#define ccomment 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#if !USE_WINDOWS
#include <unistd.h>
#endif
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * out_str ,yyscan_t yyscanner );

int yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int line_number ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 31 "sphinxql.l"


#line 1136 "llsphinxql.c"

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 546 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1195 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 33 "sphinxql.l"
{ BEGIN(ccomment); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 34 "sphinxql.l"
{ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 35 "sphinxql.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 37 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AGENT; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 38 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ALTER; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 39 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ADD; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 40 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AND; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 41 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AS; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 42 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ASC; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 43 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATTACH; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 44 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATTRIBUTES; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 45 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AVG; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 46 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BEGIN; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 47 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BETWEEN; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 48 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BIGINT; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 49 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BOOL; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 50 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BY; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 51 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CALL; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 52 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CHARACTER; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 53 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CHUNK; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 54 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLLATION; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 55 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLUMN; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 56 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMIT; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 57 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMITTED; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 58 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COUNT; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 59 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CREATE; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 60 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DATABASES; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 61 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DELETE; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 62 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESC; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 63 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESCRIBE; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 64 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DISTINCT; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 65 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DIV; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 66 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DOUBLE; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 67 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DROP; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 68 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FACET; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 69 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FALSE; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 70 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLOAT; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 71 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLUSH; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 72 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FOR; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 73 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FROM; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 74 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FUNCTION; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 75 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GLOBAL; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 76 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 77 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUPBY; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 78 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP_CONCAT; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 79 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_HAVING; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 80 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ID; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 81 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IN; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 82 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INDEX; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 83 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INSERT; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 84 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INTEGER; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 85 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INT; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 86 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INTO; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 87 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IS; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 88 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ISOLATION; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 89 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_JSON; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 90 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LEVEL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 91 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIKE; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 92 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIMIT; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 93 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MATCH; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 94 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MAX; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 95 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_META; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 96 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MIN; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 97 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MOD; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 98 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MULTI; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 99 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MULTI64; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 100 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NAMES; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 101 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NOT; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 102 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NULL; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 103 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTION; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 104 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTIMIZE; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 105 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OR; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 106 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ORDER; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 107 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLAN; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 108 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLUGIN; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 109 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLUGINS; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 110 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PROFILE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 111 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAMCHUNK; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 112 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAND; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 113 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_READ; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 114 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RECONFIGURE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 115 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPEATABLE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 116 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPLACE; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 117 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REMAP; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 118 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RETURNS; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 119 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ROLLBACK; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 120 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RTINDEX; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 121 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SELECT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 122 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SERIALIZABLE; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 123 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SET; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 124 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SETTINGS; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 125 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SESSION; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 126 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SHOW; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 127 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SONAME; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 128 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_START; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 129 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STATUS; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 130 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STRING; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 131 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUM; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 132 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TABLE; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 133 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TABLES; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 134 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_THREADS; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 135 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TO; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 136 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRANSACTION; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 137 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 138 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUNCATE; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 139 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TYPE; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 140 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UNCOMMITTED; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 141 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UPDATE; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 142 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VALUES; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 143 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VARIABLES; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 144 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WARNINGS; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 145 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WEIGHT; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 146 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WHERE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 147 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WITHIN; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 149 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 150 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 151 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LTE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 152 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GTE; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 153 "sphinxql.l"
{ YYSTOREBOUNDS; return '='; }
	YY_BREAK
case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 155 "sphinxql.l"
{ YYSTOREBOUNDS; pParser->m_pLastTokenStart = yytext; return TOK_QUOTED_STRING; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 157 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 158 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_DOT_NUMBER; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 159 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUBKEY; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 160 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 161 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iValue = (int64_t)strtoull ( yytext, NULL, 10 ); return TOK_CONST_INT; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 163 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 164 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 165 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 166 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IDENT; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 167 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BAD_NUMERIC; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 168 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_USERVAR; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 169 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SYSVAR; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 170 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SYSVAR; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 171 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; return TOK_ID; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 172 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; return TOK_IDENT; }
	YY_BREAK
case 136:
/* rule 136 can match eol */
YY_RULE_SETUP
#line 174 "sphinxql.l"
{ ; }
	YY_BREAK
case 137:
/* rule 137 can match eol */
YY_RULE_SETUP
#line 175 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUBKEY; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 176 "sphinxql.l"
{ YYSTOREBOUNDS; return yytext[0]; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 178 "sphinxql.l"
ECHO;
	YY_BREAK
#line 1917 "llsphinxql.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ccomment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 546 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 546 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 545);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_lineno called with no buffer" , yyscanner); 
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_column called with no buffer" , yyscanner); 
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 178 "sphinxql.l"



// warning, lexer generator dependent!
// flex inserts trailing zero as needed into the buffer when lexing
// but we need that rolled back when doing error reporting from yyerror
void yylex_unhold ( yyscan_t yyscanner )
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( YY_CURRENT_BUFFER )
	{
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
	}
}

#if USE_WINDOWS
#pragma warning(pop)
#endif

